﻿using System;
using System.Diagnostics;
using GHIElectronics.TinyCLR.Devices.Adc;
using GHIElectronics.TinyCLR.Devices.Gpio;
using GHIElectronics.TinyCLR.Devices.Pwm;
using GHIElectronics.TinyCLR.Pins;
using System.Threading;
using Webge.TCLR.Displays;

namespace MiniSerre
{
    class Program
    {
        static void Main()
        {
            // Variables
            var Nhumidite = 0; // MiniSerreV1
            var Npotentiometre = 0.0;  // MiniSerreV1
            var Humidite_1 = 0.0; var Humidite = 0.0;
            var ConsigneVitesse_1 = 0.0; var ConsigneVitesse = 0.0;

            // Création des objets pour une carte FEZ T18
            // Pour une carte FEZ PANDA 3, remplacer FEZ par FEZPandaIII
            //-----------------------------------------------------------------
            // CAN
            var adc = AdcController.GetDefault();
            var potentiometre = adc.OpenChannel(FEZ.AdcChannel.A1); // A connecter sur I1 Tinkerkit
            var CptHumidite = adc.OpenChannel(FEZ.AdcChannel.A0); // A connecter sur I0 Tinkerkit

            // PWM
            var pwm = PwmController.FromName(FEZ.PwmChannel.Controller3.Id); // Connecter ventilateur sur B Ardumoto
            var CdeVentilation = pwm.OpenChannel(FEZ.PwmChannel.Controller3.D11);
            pwm.SetDesiredFrequency(5000);

            // GPIO
            var gpio = GpioController.GetDefault();
            var SENS = gpio.OpenPin(FEZ.GpioPin.D13);
            SENS.SetDriveMode(GpioPinDriveMode.Output);
            SENS.Write(GpioPinValue.Low);
            var Alarme = gpio.OpenPin(FEZ.GpioPin.D5);  // A connecter sur O4 Tinkerkit 
            Alarme.SetDriveMode(GpioPinDriveMode.Output);
            Alarme.Write(GpioPinValue.Low);

            // Afficheur
            var lcd = new ELCD162(); // A connecter sur Serial Tinkerkit

            // Initialisation
            //-----------------------------------------------------------------
            CdeVentilation.SetActiveDutyCyclePercentage(0);
            CdeVentilation.Start();
            lcd.Init(); lcd.CursorOff();

            while (true)
            {
                // Lire l'humidité
                Nhumidite = CptHumidite.ReadValue();  // MiniSerreV1
                Npotentiometre = potentiometre.ReadValue();   // MiniSerreV2

                // Traiter
                Humidite = 0.026 * Nhumidite - 25.8;   // MiniSerreV1
                ConsigneVitesse = Npotentiometre / 4095; // MiniSerreV2

                if (Humidite > 80) // MiniSerreV2bis
                {
                    Alarme.Write(GpioPinValue.High);
                }
                else
                {
                    Alarme.Write(GpioPinValue.Low);
                }

                if (Humidite > 70) // MiniSerreV2
                {
                    CdeVentilation.SetActiveDutyCyclePercentage(ConsigneVitesse);
                }
                else
                {
                    CdeVentilation.SetActiveDutyCyclePercentage(0);
                }

                // Afficher l'humidité et la consigne de vitesse
                if ((Humidite != Humidite_1) || (ConsigneVitesse != ConsigneVitesse_1))
                {
                    lcd.ClearScreen();
                    lcd.PutString("Hum=" + Humidite.ToString("F0") + "%");   // MiniSerreV1
                                                                             //Debug.WriteLine("ConsigneVitesse= " + ConsigneVitesse);
                    lcd.SetCursor(0, 1); // MiniSerreV2
                    lcd.PutString("CVit=" + (100 * ConsigneVitesse).ToString("F0") + "%"); // MiniSerreV2
                                                                                           //Debug.WriteLine("Nhumidite= " + Nhumidite);
                    Humidite_1 = Humidite; ConsigneVitesse_1 = ConsigneVitesse;
                }
                Thread.Sleep(500);
            }

        }
    }
}
